package com.hgwebservice.dal.dataobject.data;

import cn.hutool.core.lang.Dict;
import com.baomidou.mybatisplus.annotation.KeySequence;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.*;

import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * 管理后台的用户 DO
 */
@TableName(value = "system_users", autoResultMap = true) // 由于 SQL Server 的 system_user 是关键字，所以使用 system_users
@KeySequence("system_user_seq") // 用于 Oracle、PostgreSQL、Kingbase、DB2、H2 数据库的主键自增。如果是 MySQL 等数据库，可不写。
@Data
@EqualsAndHashCode(callSuper = true)
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class AdminUserDO extends BaseDO {

    /**
     * 用户ID
     */
    @TableId
    @JsonFormat(shape = JsonFormat.Shape.STRING)
    protected Long id;

    /**
     * 关联其他医院用户主键
     */
    protected String code;

    /**
     * 用户账号
     */

    protected String username;

    protected String salt;
    /**
     * 加密后的密码
     * <p>
     */
    protected String password;
    /**
     * 用户昵称
     */
    protected String nickname;
    /**
     * 备注
     */
    protected String remark;
    /**
     * 部门 ID
     */
    protected Long deptId;


    protected String deptIds;
    @TableField(exist = false)
    protected String deptName;
    @TableField(exist = false)
    protected String tenantName;
    @TableField(exist = false)
    protected String type;

    /**
     * 岗位编号数组
     */
//    @TableField(typeHandler = JsonLongSetTypeHandler.class)
    protected Set<Long> postIds;
    /**
     * 用户邮箱
     */
    protected String email;
    /**
     * 手机号码
     */
    protected String mobile;
    /**
     * 用户性别
     * <p>
     * 枚举类 {@link SexEnum}
     */
    protected Integer sex;
    /**
     * 用户头像
     */
    protected String avatar;
    /**
     * 帐号状态
     * <p>
     * 枚举 {@link CommonStatusEnum}
     */
    protected Integer status;
    /**
     * 最后登录IP
     */
    protected String loginIp;
    /**
     * 最后登录时间
     */
    protected Date loginDate;


    /**
     * 身份证号
     */
    protected String cardNo;


    protected String cardFrontImage;

    protected String cardBackImage;


    protected Date birthday;

    /**
     * 执业证书号
     */
    protected String certNo;


    protected String certImage;
    /**
     * 工号
     */
    protected String workNumber;


    protected String weixinId;


    protected String yunxinAccid;


    protected String yunxinToken;


    protected Integer position;

    protected Integer title;

    protected String description;


    protected String experience;

    protected String specialty;

    protected String learning;

    protected Integer interactionTimes;

    @TableField(exist = false)
    protected List<String> roleCodeList;
    @TableField(exist = false)
    protected String roleCodes;
    @TableField(exist = false)
    protected String roleNames;

    protected Integer verifyStatus;

    protected  Integer isLocked;

    protected  Integer isChat;

    @TableField(exist = false)
    protected  Date passwordSetTime;
    // crm中代表的saleId
    protected Long crmSaleId;

    private String productId;

    /**
     * 移动端平台
     */
    private String platform;
    /**
     * 移动端设备名称
     */
    private String deviceName;
    /**
     * 移动端设备版本
     */
    private String deviceVersion;
    /**
     * 移动端版本
     */
    private String version;
    /**
     * 极光推送的id
     */
    private String pushId;

    /**
     * 信息安全确认状态（0：未确认，1：已确认）
     */
    private Integer infoConfirmStatus;

    /**
     * 信息安全确认时间
     */
    private Date infoConfirmTime;

    @TableField(exist = false)
    private List<Dict> deptIdList;

    private Date freezeTime;
    @TableField(exist = false)
    private Integer province;
    @TableField(exist = false)
    private Integer city;
    @TableField(exist = false)
    private Integer region;

    @TableField(exist = false)
    private String provinceName;
    @TableField(exist = false)
    private String cityName;
    @TableField(exist = false)
    private String crmDeptName;
    @TableField(exist = false)
    private String saleName;
    @TableField(exist = false)
    private String groupName;
    private Integer isUseDevice;

}
