package com.hgwebservice.dal.dataobject.data;

import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.annotation.KeySequence;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.*;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * 用户血糖数据 DO
 *
 * @author 管理员
 */
@TableName("cdm_user_blood_sugar")
@KeySequence("user_blood_sugar_seq") // 用于 Oracle、PostgreSQL、Kingbase、DB2、H2 数据库的主键自增。如果是 MySQL 等数据库，可不写。
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class UserBloodSugarDO extends BaseDO {

    /**
     * 自增id
     */
    @TableId
    private Integer id;
    /**
     * 用户id
     */
    @JsonFormat(shape = JsonFormat.Shape.STRING)
    private Long userId;
    /**
     * 临床修改原来id
     */
    private Integer editBloodId;
    /**
     * 医生id
     */
    private Long recordUserId;
    @TableField(exist = false)
    private String recordUserName;
    /**
     * 录入类型 1-自动 2-手动
     */
    private Integer type;
    /**
     * 量测结果值
     */
    @TableField("measureValue")
    private Float measureValue;
    /**
     * 量测结果原值
     */
    @TableField("measureValue2")
    private String measureValue2;
    /**
     * 量测单位 mg/dL 或 mmol/L
     */
    @TableField("measureUnit")
    private String measureUnit;
    /**
     * 量测时间
     */
    @TableField("measureDate")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "Asia/Shanghai")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date measureDate;
    /**
     * 时区
     */
    @TableField("timeZone")
    private String timeZone;
    /**
     * 用餐标记 0-NONE,1-After meal,2-Before Meal,3-STAT
     */
    private Integer mark;
    /**
     * 用餐时段 0-Bedtime,1-Breakfast,2-Lunch,3-Dinner,4-Others,5-idnight,6-WakeUp
     */
    private Integer period;

    /**
     * 餐段
     */
    @TableField(exist = false)
    private String periodMark;

    @TableField(exist = false)
    private String prodMark;
    /**
     * 项目id
     */
    private Integer productName;
    /**
     * 血糖仪序号
     */
    @TableField("meterSn")
    private String meterSn;
    /**
     * 碳水化合物 单位/克
     */
    private String carbohydrates;
    /**
     * 胰岛素类型 1-速效型,2-混合型,3-長效型
     */
    private Integer insulinType;
    /**
     * 胰岛素使用剂量
     */
    private String insulinServing;
    /**
     * 运动类型 1-騎車,2-健身,3-游泳,4-跑步,5-有氧運動,6-瑜珈,7-走路
     */
    private Integer sportType;
    /**
     * 运动时间
     */
    private String sportDuration;
    /**
     * 日期
     */
    private String date;
    /**
     * 量测备注
     */
    private String note;
    /**
     * 医生是否阅读过血糖数据 0没有 1有 2无
     */
    private Integer isRead;
    /**
     * 医生是否阅读过高危血糖数据 0没有 1有 2无
     */
    private Integer isHighRead;
    /**
     * 数据来源 1你的医生(包括小程序) 2瑞特健康拉取
     */
    private Integer isMy;
    /**
     * 状态: 0.开启 1.关闭
     */
    private Integer status;
    /**
     * 是否为异常温度数据：0-正常数据，1-异常数据
     */
    @TableField("isAccpecttable")
    private Integer isAccpecttable;
    /**
     * 是否为质控数据：0-正常测量，1-质控
     */
    @TableField("isQualityControl")
    private Integer isQualityControl;

    private String code;
    private Long tenantId;
    private Integer source;
    private Integer isFee;
}
